==> pg_monitor-1.4.33.tar.gz: pg_monitor-1.4.33/pg_monitor/connection.py <==
#!/usr/bin/python 

import time
import sql
import math


def getConnections( param=None ) :
        item_name = 'POSTGRES_CONNECTIONS'
        status = []
        perfdata = '-'
        output = ''
        if param != None :
                query = "SELECT \
                              datname \
                         FROM \
                              pg_database \
                         WHERE datistemplate is FALSE"
	
		host = param['host'][0]
		port = param['port'][0]

                results = sql.getSQLResult ( {'host': host , 'port' : port, 'dbname': 'postgres', 'user' : param['user'] ,'password' : param['password'] } ,query )
		if results[0] == None :
			return '2' + ' ' + 'POSTGRES_CONNECTIONS' + ' ' + '-' + ' ' + results[1]
	
		dbs = results[1]

		for db in dbs :
			query = "select version()"
			begin = time.time()
			row = sql.getSQLResult ( {'host': host , 'port' : port, 'dbname': db[0], 'user' : param['user'] ,'password' : param['password'] } ,query )
			duration = int ( math.ceil ( ( time.time() - begin ) * 1000 ) )
			out_add = 'connection test took {0:s} ms '
			if row != None :
				status.append(0)
			else :
				status.append(2)
				out_add = ' refuses connection !!! {0:s}'
				duration = ''

                       	if perfdata == '-' :
                               	perfdata = db[0] + '=' + str( duration )
                               	output =  '{0:s} {1:s}'.format(db[0], out_add.format(str(duration) ) )
                       	elif perfdata != '-'  :
                               	perfdata = perfdata + '|' + db[0] + '=' + str ( duration )
                               	output =  output + '; {0:s} {1:s}'.format(db[0], out_add.format(str(duration) ) )


                status.sort( reverse=True )
                return str(status[0]) + ' ' + item_name + ' ' + str(perfdata) + ' ' + output
## testing the function 
#if __name__ == '__main__' :
#        print ( getConnections( {'host' : 'localhost', 'port' : '5432' ,'user' : 'postgres' , 'password' : '' } )  )

==> pg_monitor-1.5.8.tar.gz: pg_monitor-1.5.8/pg_monitor/connection.py <==
#!/usr/bin/python 

import time
import sql
import math


def getConnections( param=None ) :
        item_name = 'POSTGRES_CONNECTIONS'
        status = []
        perfdata = '-'
        output = ''
        if param != None :
                query = "SELECT \
                              datname \
                         FROM \
                              pg_database \
                         WHERE datistemplate is FALSE"
	
		host = param['host'][0]
		port = param['port'][0]

                results = sql.getSQLResult ( {'host': host , 'port' : port, 'dbname': param['dbname'], 'user' : param['user'] ,'password' : param['password'] } ,query )
		if results[0] == None :
			return '2' + ' ' + 'POSTGRES_CONNECTIONS' + ' ' + '-' + ' ' + results[1]
	
		dbs = results[1]

		for db in dbs :
			query = "select version()"
			begin = time.time()
			row = sql.getSQLResult ( {'host': host , 'port' : port, 'dbname': db[0], 'user' : param['user'] ,'password' : param['password'] } ,query )
			duration = int ( math.ceil ( ( time.time() - begin ) * 1000 ) )
			out_add = 'connection test took {0:s} ms '
			if row != None :
				status.append(0)
			else :
				status.append(2)
				out_add = ' refuses connection !!! {0:s}'
				duration = ''

                       	if perfdata == '-' :
                               	perfdata = db[0] + '=' + str( duration )
                               	output =  '{0:s} {1:s}'.format(db[0], out_add.format(str(duration) ) )
                       	elif perfdata != '-'  :
                               	perfdata = perfdata + '|' + db[0] + '=' + str ( duration )
                               	output =  output + '; {0:s} {1:s}'.format(db[0], out_add.format(str(duration) ) )


                status.sort( reverse=True )
                return str(status[0]) + ' ' + item_name + ' ' + str(perfdata) + ' ' + output
